==> icecat-45.7.0-gnu1.tar.bz2: icecat-45.7.0/testing/mozharness/configs/releases/bouncer_icecat_beta.py <==
# lint_ignore=E501
config = {
    "shipped-locales-url": "https://hg.mozilla.org/%(repo)s/raw-file/%(revision)s/browser/locales/shipped-locales",
    "products": {
        "installer": {
            "product-name": "IceCat-%(version)s",
            "check_uptake": True,
            "alias": "icecat-beta-latest",
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/linux-i686/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/linux-x86_64/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/mac/:lang/IceCat%%20%(version)s.dmg",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/win64/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win64",
                },
            },
        },
        "installer-ssl": {
            "product-name": "IceCat-%(version)s-SSL",
            "check_uptake": True,
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/linux-i686/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/linux-x86_64/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/mac/:lang/IceCat%%20%(version)s.dmg",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/win64/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win64",
                },
            },
        },
        "stub-installer": {
            "product-name": "IceCat-%(version)s-stub",
            "check_uptake": True,
            "alias": "icecat-beta-stub",
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20Stub%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
            },
        },
        "sha1-installer": {
            "product-name": "IceCat-%(version)s-sha1",
            # TODO: enable when sha1 installers are automated in bug 1290179
            "check_uptake": False,
            # TODO: enable when sha1 installers are automated in bug 1290179
            # "alias": "icecat-beta-sha1",
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32-sha1/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
            },
        },
        "complete-mar": {
            "product-name": "IceCat-%(version)s-Complete",
            "check_uptake": True,
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/update/linux-i686/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/update/linux-x86_64/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/update/mac/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/update/win32/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/update/win64/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "win64",
                },
            },
        },
    },
    "partials": {
        "releases-dir": {
            "product-name": "IceCat-%(version)s-Partial-%(prev_version)s",
            "check_uptake": True,
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/update/linux-i686/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/update/linux-x86_64/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/update/mac/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/update/win32/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/update/win64/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "win64",
                },
            },
        },
    },
}

==> icecat-52.0.2-gnu1.tar.bz2: icecat-52.0.2/testing/mozharness/configs/releases/bouncer_icecat_beta.py <==
# lint_ignore=E501
config = {
    "shipped-locales-url": "https://hg.mozilla.org/%(repo)s/raw-file/%(revision)s/browser/locales/shipped-locales",
    "products": {
        "installer": {
            "product-name": "IceCat-%(version)s",
            "check_uptake": True,
            "alias": "icecat-beta-latest",
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/linux-i686/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/linux-x86_64/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/mac/:lang/IceCat%%20%(version)s.dmg",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/win64/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win64",
                },
            },
        },
        "installer-ssl": {
            "product-name": "IceCat-%(version)s-SSL",
            "check_uptake": True,
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/linux-i686/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/linux-x86_64/:lang/icecat-%(version)s.tar.bz2",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/mac/:lang/IceCat%%20%(version)s.dmg",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/win64/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win64",
                },
            },
        },
        "stub-installer": {
            "product-name": "IceCat-%(version)s-stub",
            "check_uptake": True,
            "alias": "icecat-beta-stub",
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32/:lang/IceCat%%20Setup%%20Stub%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
            },
        },
        "sha1-installer": {
            "product-name": "IceCat-%(version)s-sha1",
            "check_uptake": True,
            "alias": "icecat-beta-sha1",
            "ssl-only": True,
            "add-locales": True,
            "paths": {
                "win32": {
                    "path": "/icecat/releases/%(version)s/win32-sha1/:lang/IceCat%%20Setup%%20%(version)s.exe",
                    "bouncer-platform": "win",
                },
            },
        },
        "complete-mar": {
            "product-name": "IceCat-%(version)s-Complete",
            "check_uptake": True,
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/update/linux-i686/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/update/linux-x86_64/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/update/mac/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/update/win32/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/update/win64/:lang/icecat-%(version)s.complete.mar",
                    "bouncer-platform": "win64",
                },
            },
        },
    },
    "partials": {
        "releases-dir": {
            "product-name": "IceCat-%(version)s-Partial-%(prev_version)s",
            "check_uptake": True,
            "ssl-only": False,
            "add-locales": True,
            "paths": {
                "linux": {
                    "path": "/icecat/releases/%(version)s/update/linux-i686/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "linux",
                },
                "linux64": {
                    "path": "/icecat/releases/%(version)s/update/linux-x86_64/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "linux64",
                },
                "macosx64": {
                    "path": "/icecat/releases/%(version)s/update/mac/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "osx",
                },
                "win32": {
                    "path": "/icecat/releases/%(version)s/update/win32/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "win",
                },
                "win64": {
                    "path": "/icecat/releases/%(version)s/update/win64/:lang/icecat-%(prev_version)s-%(version)s.partial.mar",
                    "bouncer-platform": "win64",
                },
            },
        },
    },
}
